theme_data = {"themes": [{"lessVariables": "http://bootswatch.com/amelia/variables.less", "name": "Amelia", "less": "http://bootswatch.com/amelia/bootswatch.less", "thumbnail": "http://bootswatch.com/amelia/thumbnail.png", "preview": "http://bootswatch.com/amelia/", "cssMin": "http://bootswatch.com/amelia/bootstrap.min.css", "css": "http://bootswatch.com/amelia/bootstrap.css", "description": "Sweet and cheery"}, {"lessVariables": "http://bootswatch.com/cerulean/variables.less", "name": "Cerulean", "less": "http://bootswatch.com/cerulean/bootswatch.less", "thumbnail": "http://bootswatch.com/cerulean/thumbnail.png", "preview": "http://bootswatch.com/cerulean/", "cssMin": "http://bootswatch.com/cerulean/bootstrap.min.css", "css": "http://bootswatch.com/cerulean/bootstrap.css", "description": "A calm blue sky"}, {"lessVariables": "http://bootswatch.com/cosmo/variables.less", "name": "Cosmo", "less": "http://bootswatch.com/cosmo/bootswatch.less", "thumbnail": "http://bootswatch.com/cosmo/thumbnail.png", "preview": "http://bootswatch.com/cosmo/", "cssMin": "http://bootswatch.com/cosmo/bootstrap.min.css", "css": "http://bootswatch.com/cosmo/bootstrap.css", "description": "An ode to Metro"}, {"lessVariables": "http://bootswatch.com/cyborg/variables.less", "name": "Cyborg", "less": "http://bootswatch.com/cyborg/bootswatch.less", "thumbnail": "http://bootswatch.com/cyborg/thumbnail.png", "preview": "http://bootswatch.com/cyborg/", "cssMin": "http://bootswatch.com/cyborg/bootstrap.min.css", "css": "http://bootswatch.com/cyborg/bootstrap.css", "description": "Jet black and electric blue"}, {"lessVariables": "http://bootswatch.com/flatly/variables.less", "name": "Flatly", "less": "http://bootswatch.com/flatly/bootswatch.less", "thumbnail": "http://bootswatch.com/flatly/thumbnail.png", "preview": "http://bootswatch.com/flatly/", "cssMin": "http://bootswatch.com/flatly/bootstrap.min.css", "css": "http://bootswatch.com/flatly/bootstrap.css", "description": "Flat and modern"}, {"lessVariables": "http://bootswatch.com/journal/variables.less", "name": "Journal", "less": "http://bootswatch.com/journal/bootswatch.less", "thumbnail": "http://bootswatch.com/journal/thumbnail.png", "preview": "http://bootswatch.com/journal/", "cssMin": "http://bootswatch.com/journal/bootstrap.min.css", "css": "http://bootswatch.com/journal/bootstrap.css", "description": "Crisp like a new sheet of paper."}, {"lessVariables": "http://bootswatch.com/readable/variables.less", "name": "Readable", "less": "http://bootswatch.com/readable/bootswatch.less", "thumbnail": "http://bootswatch.com/readable/thumbnail.png", "preview": "http://bootswatch.com/readable/", "cssMin": "http://bootswatch.com/readable/bootstrap.min.css", "css": "http://bootswatch.com/readable/bootstrap.css", "description": "Optimized for legibility"}, {"lessVariables": "http://bootswatch.com/simplex/variables.less", "name": "Simplex", "less": "http://bootswatch.com/simplex/bootswatch.less", "thumbnail": "http://bootswatch.com/simplex/thumbnail.png", "preview": "http://bootswatch.com/simplex/", "cssMin": "http://bootswatch.com/simplex/bootstrap.min.css", "css": "http://bootswatch.com/simplex/bootstrap.css", "description": "Mini and minimalist."}, {"lessVariables": "http://bootswatch.com/slate/variables.less", "name": "Slate", "less": "http://bootswatch.com/slate/bootswatch.less", "thumbnail": "http://bootswatch.com/slate/thumbnail.png", "preview": "http://bootswatch.com/slate/", "cssMin": "http://bootswatch.com/slate/bootstrap.min.css", "css": "http://bootswatch.com/slate/bootstrap.css", "description": "Shades of gunmetal gray"}, {"lessVariables": "http://bootswatch.com/spacelab/variables.less", "name": "Spacelab", "less": "http://bootswatch.com/spacelab/bootswatch.less", "thumbnail": "http://bootswatch.com/spacelab/thumbnail.png", "preview": "http://bootswatch.com/spacelab/", "cssMin": "http://bootswatch.com/spacelab/bootstrap.min.css", "css": "http://bootswatch.com/spacelab/bootstrap.css", "description": "Silvery and sleek."}, {"lessVariables": "http://bootswatch.com/united/variables.less", "name": "United", "less": "http://bootswatch.com/united/bootswatch.less", "thumbnail": "http://bootswatch.com/united/thumbnail.png", "preview": "http://bootswatch.com/united/", "cssMin": "http://bootswatch.com/united/bootstrap.min.css", "css": "http://bootswatch.com/united/bootstrap.css", "description": "Ubuntu orange and unique font"}], "version": "3.0.0"}


from django import template
from django.contrib.staticfiles.storage import staticfiles_storage
from .. import get_script, get_styles

register = template.Library()

@register.simple_tag
def bootstrap_script(use_min=True):
    return '<script type="text/javascript" src="%(script_file)s"></script>' % dict(script_file=get_script(use_min))

@register.simple_tag
def bootstrap_styles(theme='default', type='min.css'):
    if type == 'min.css' or type == 'css':
        subdir = 'css'
        fileext = type
        mimetype = 'text/css'
    elif type == 'less':
        subdir = type
        fileext = type
        mimetype = 'text/less'
    return '<link rel="stylesheet" href="%(theme_file)s" type="%(mimetype)s">' % dict(theme_file=get_styles(theme, subdir, fileext), mimetype=mimetype)



#!/usr/bin/env python

from setuptools import setup, find_packages

version = '3.0.2'

setup(
    name='django-bootstrap-themes',
    version=version,
    description="Bootstrap theme support for Django.",
    long_description=open("README.md", "r").read(),
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Environment :: Web Environment",
        "Intended Audience :: End Users/Desktop",
        "Natural Language :: English",
        "Operating System :: OS Independent",
        "Framework :: Django",
        "Programming Language :: Python",
        "Topic :: Internet :: WWW/HTTP :: Dynamic Content :: CGI Tools/Libraries",
        "Topic :: Utilities",
        "License :: OSI Approved :: MIT License",
    ],
    keywords='django bootstrap themes',
    author='T. Scott Barnes',
    author_email='tsbarnes@tsbarnes.com',
    url='http://github.com/no-dice/django-bootstrap-themes',
    license='MIT',
    packages=find_packages(),
    install_requires=[
        'django>=1.4',
    ],
    include_package_data=True,
    zip_safe=False,
)



from django.contrib.staticfiles.storage import staticfiles_storage

available_themes = (
    ('default', 'Default'),
    ('amelia', 'Amelia'),
    ('cerulean', 'Cerulean'),
    ('cosmo', 'Cosmo'),
    ('cyborg', 'Cyborg'),
    ('flatly', 'Flatly'),
    ('journal', 'Journal'),
    ('readable', 'Readable'),
    ('simplex', 'Simplex'),
    ('slate', 'Slate'),
    ('spacelab', 'SpaceLab'),
    ('united', 'United'),
)

def list_themes():
    return available_themes

def get_script(use_min=True):
    minified = ''
    if use_min:
        minified = '.min'
    return staticfiles_storage.url('bootstrap/js/bootstrap%(minified)s.js' % dict(minified=minified))

def get_styles(theme='default', subdir='css', fileext='min.css'):
    if (not theme) or (theme == ''):
        theme = 'default'
    return staticfiles_storage.url('bootstrap/themes/%(theme)s/%(subdir)s/bootstrap.%(fileext)s' % dict(theme=theme, subdir=subdir, fileext=fileext))
